window.Gleam.initSearch([{"doc":"glambda","title":"glambda","content":"# glambda\n\nWrite AWS Lambda functions in Gleam!\n\n[![Package Version](https://img.shields.io/hexpm/v/glambda)](https://hex.pm/packages/glambda)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/glambda/)\n\nWrite your Lambda function as an [http](https://github.com/gleam-lang/http) handler, or accept direct events as normal Gleam types.\n\nGlambda only supports the JavaScript target. Your compiled code uses the AWS Lambda Node.js runtime.\n\n```sh\ngleam add glambda\n```\n\n## HTTP Handler\n\n```gleam\nimport glambda.{type Context}\nimport gleam/http/request.{type Request}\nimport gleam/http/response.{type Response, Response}\nimport gleam/javascript/promise.{type Promise}\nimport gleam/option.{type Option, Some}\n\nfn handle_request(\n  _req: Request(Option(String)),\n  ctx: Context,\n) -&gt; Promise(Response(Option(String))) {\n  let json = &quot;{\\&quot;functionName\\&quot;: \\&quot;&quot; &lt;&gt; ctx.function_name &lt;&gt; &quot;\\&quot;}&quot;\n  Response(\n    200,\n    [#(&quot;content-type&quot;, &quot;application/json; charset=utf-8&quot;)],\n    Some(json),\n  )\n  |&gt; promise.resolve\n}\n\n// This is the actual function lambda invokes\npub fn handler(event, ctx) {\n  glambda.http_handler(handle_request)(event, ctx)\n}\n```\n\n## Event Handler\n\n```gleam\nimport glambda.{\n  type ApiGatewayProxyEventV2, type ApiGatewayProxyResultV2, type Context,\n  ApiGatewayProxyResultV2,\n}\nimport gleam/dict\nimport gleam/javascript/promise.{type Promise}\nimport gleam/option.{Some}\n\nfn event_handler(\n  _event: ApiGatewayProxyEventV2,\n  ctx: Context,\n) -&gt; Promise(ApiGatewayProxyResultV2) {\n  ApiGatewayProxyResultV2(\n    status_code: 200,\n    headers: dict.from_list([#(&quot;content-type&quot;, &quot;application/json&quot;)]),\n    body: Some(&quot;{\\&quot;functionName\\&quot;: \\&quot;&quot; &lt;&gt; ctx.function_name &lt;&gt; &quot;\\&quot;}&quot;),\n    is_base64_encoded: False,\n    cookies: [],\n  )\n  |&gt; promise.resolve\n}\n\n// This is the actual function lambda invokes\npub fn handler(event, ctx) {\n  glambda.api_gateway_proxy_v2_handler(event_handler)(event, ctx)\n}\n```\n\nCheck out the [examples](https://github.com/ryanmiville/glambda/tree/main/examples) directory for examples of each supported event type, deployable with [SST](https://github.com/sst/sst).\n\n## Supported Events\n* `ApiGatewayProxyEventV2` (can be handled directly or as a `Request(Option(String))`)\n* `EventBridgeEvent`\n* `SqsEvent`\n\nFurther documentation can be found at &lt;https://hexdocs.pm/glambda&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"glambda","title":"ApiGatewayEventClientCertificate","content":"pub type ApiGatewayEventClientCertificate {\n  ApiGatewayEventClientCertificate(\n    client_cert_pem: String,\n    issuer_dn: String,\n    serial_number: String,\n    subject_dn: String,\n    validity: ApiGatewayEventValidity,\n  )\n}\n\nApiGatewayEventClientCertificate(\n  client_cert_pem: String,\n  issuer_dn: String,\n  serial_number: String,\n  subject_dn: String,\n  validity: ApiGatewayEventValidity,\n)\n\n\nSynonyms:\nglambda.ApiGatewayEventClientCertificate\nglambda ApiGatewayEventClientCertificate","url":"glambda.html#ApiGatewayEventClientCertificate"},{"doc":"glambda","title":"ApiGatewayEventRequestContextAuthentication","content":"pub type ApiGatewayEventRequestContextAuthentication {\n  ApiGatewayEventRequestContextAuthentication(\n    client_cert: ApiGatewayEventClientCertificate,\n  )\n}\n\nApiGatewayEventRequestContextAuthentication(\n  client_cert: ApiGatewayEventClientCertificate,\n)\n\n\nSynonyms:\nglambda.ApiGatewayEventRequestContextAuthentication\nglambda ApiGatewayEventRequestContextAuthentication","url":"glambda.html#ApiGatewayEventRequestContextAuthentication"},{"doc":"glambda","title":"ApiGatewayEventRequestContextHttp","content":"pub type ApiGatewayEventRequestContextHttp {\n  ApiGatewayEventRequestContextHttp(\n    method: String,\n    path: String,\n    protocol: String,\n    source_ip: String,\n    user_agent: String,\n  )\n}\n\nApiGatewayEventRequestContextHttp(\n  method: String,\n  path: String,\n  protocol: String,\n  source_ip: String,\n  user_agent: String,\n)\n\n\nSynonyms:\nglambda.ApiGatewayEventRequestContextHttp\nglambda ApiGatewayEventRequestContextHttp","url":"glambda.html#ApiGatewayEventRequestContextHttp"},{"doc":"glambda","title":"ApiGatewayEventRequestContextIamAuthorizer","content":"pub type ApiGatewayEventRequestContextIamAuthorizer {\n  ApiGatewayEventRequestContextIamAuthorizer(\n    access_key: String,\n    account_id: String,\n    caller_id: String,\n    principal_org_id: String,\n    user_arn: String,\n    user_id: String,\n  )\n}\n\nApiGatewayEventRequestContextIamAuthorizer(\n  access_key: String,\n  account_id: String,\n  caller_id: String,\n  principal_org_id: String,\n  user_arn: String,\n  user_id: String,\n)\n\n\nSynonyms:\nglambda.ApiGatewayEventRequestContextIamAuthorizer\nglambda ApiGatewayEventRequestContextIamAuthorizer","url":"glambda.html#ApiGatewayEventRequestContextIamAuthorizer"},{"doc":"glambda","title":"ApiGatewayEventRequestContextJwtAuthorizer","content":"pub type ApiGatewayEventRequestContextJwtAuthorizer {\n  ApiGatewayEventRequestContextJwtAuthorizer(\n    claims: Dict(String, String),\n    scopes: Option(List(String)),\n  )\n}\n\nApiGatewayEventRequestContextJwtAuthorizer(\n  claims: Dict(String, String),\n  scopes: Option(List(String)),\n)\n\n\nSynonyms:\nglambda.ApiGatewayEventRequestContextJwtAuthorizer\nglambda ApiGatewayEventRequestContextJwtAuthorizer","url":"glambda.html#ApiGatewayEventRequestContextJwtAuthorizer"},{"doc":"glambda","title":"ApiGatewayEventValidity","content":"pub type ApiGatewayEventValidity {\n  ApiGatewayEventValidity(not_after: String, not_before: String)\n}\n\nApiGatewayEventValidity(not_after: String, not_before: String)\n\n\nSynonyms:\nglambda.ApiGatewayEventValidity\nglambda ApiGatewayEventValidity","url":"glambda.html#ApiGatewayEventValidity"},{"doc":"glambda","title":"ApiGatewayProxyEventV2","content":"pub type ApiGatewayProxyEventV2 {\n  ApiGatewayProxyEventV2(\n    version: String,\n    route_key: String,\n    raw_path: String,\n    raw_query_string: String,\n    cookies: Option(List(String)),\n    headers: Dict(String, String),\n    query_string_parameters: Option(Dict(String, String)),\n    path_parameters: Option(Dict(String, String)),\n    stage_variables: Option(Dict(String, String)),\n    request_context: ApiGatewayRequestContextV2,\n    body: Option(String),\n    is_base64_encoded: Bool,\n  )\n}\n\nApiGatewayProxyEventV2(\n  version: String,\n  route_key: String,\n  raw_path: String,\n  raw_query_string: String,\n  cookies: Option(List(String)),\n  headers: Dict(String, String),\n  query_string_parameters: Option(Dict(String, String)),\n  path_parameters: Option(Dict(String, String)),\n  stage_variables: Option(Dict(String, String)),\n  request_context: ApiGatewayRequestContextV2,\n  body: Option(String),\n  is_base64_encoded: Bool,\n)\n\n\nSynonyms:\nglambda.ApiGatewayProxyEventV2\nglambda ApiGatewayProxyEventV2","url":"glambda.html#ApiGatewayProxyEventV2"},{"doc":"glambda","title":"ApiGatewayProxyResultV2","content":"pub type ApiGatewayProxyResultV2 {\n  ApiGatewayProxyResultV2(\n    status_code: Int,\n    headers: Dict(String, String),\n    body: Option(String),\n    is_base64_encoded: Bool,\n    cookies: List(String),\n  )\n}\n\nApiGatewayProxyResultV2(\n  status_code: Int,\n  headers: Dict(String, String),\n  body: Option(String),\n  is_base64_encoded: Bool,\n  cookies: List(String),\n)\n\n\nSynonyms:\nglambda.ApiGatewayProxyResultV2\nglambda ApiGatewayProxyResultV2","url":"glambda.html#ApiGatewayProxyResultV2"},{"doc":"glambda","title":"ApiGatewayRequestContextAuthorizer","content":"pub type ApiGatewayRequestContextAuthorizer {\n  Iam(iam: ApiGatewayEventRequestContextIamAuthorizer)\n  Jwt(\n    principal_id: String,\n    integration_latency: Int,\n    jwt: ApiGatewayEventRequestContextJwtAuthorizer,\n  )\n  Lambda(lambda: Dynamic)\n}\n\nIam(iam: ApiGatewayEventRequestContextIamAuthorizer)\n\n\nJwt(\n  principal_id: String,\n  integration_latency: Int,\n  jwt: ApiGatewayEventRequestContextJwtAuthorizer,\n)\n\n\nLambda(lambda: Dynamic)\n\n\nSynonyms:\nglambda.ApiGatewayRequestContextAuthorizer\nglambda ApiGatewayRequestContextAuthorizer","url":"glambda.html#ApiGatewayRequestContextAuthorizer"},{"doc":"glambda","title":"ApiGatewayRequestContextV2","content":"pub type ApiGatewayRequestContextV2 {\n  ApiGatewayRequestContextV2(\n    route_key: String,\n    account_id: String,\n    stage: String,\n    request_id: String,\n    authorizer: Option(ApiGatewayRequestContextAuthorizer),\n    api_id: String,\n    domain_name: String,\n    domain_prefix: String,\n    time: String,\n    time_epoch: Int,\n    http: ApiGatewayEventRequestContextHttp,\n    authentication: Option(\n      ApiGatewayEventRequestContextAuthentication,\n    ),\n  )\n}\n\nApiGatewayRequestContextV2(\n  route_key: String,\n  account_id: String,\n  stage: String,\n  request_id: String,\n  authorizer: Option(ApiGatewayRequestContextAuthorizer),\n  api_id: String,\n  domain_name: String,\n  domain_prefix: String,\n  time: String,\n  time_epoch: Int,\n  http: ApiGatewayEventRequestContextHttp,\n  authentication: Option(\n    ApiGatewayEventRequestContextAuthentication,\n  ),\n)\n\n\nSynonyms:\nglambda.ApiGatewayRequestContextV2\nglambda ApiGatewayRequestContextV2","url":"glambda.html#ApiGatewayRequestContextV2"},{"doc":"glambda","title":"ClientContext","content":"pub type ClientContext {\n  ClientContext(\n    client: ClientContextClient,\n    custom: Option(Dynamic),\n    env: ClientContextEnv,\n  )\n}\n\nClientContext(\n  client: ClientContextClient,\n  custom: Option(Dynamic),\n  env: ClientContextEnv,\n)\n\n\nSynonyms:\nglambda.ClientContext\nglambda ClientContext","url":"glambda.html#ClientContext"},{"doc":"glambda","title":"ClientContextClient","content":"pub type ClientContextClient {\n  ClientContextClient(\n    installation_id: String,\n    app_title: String,\n    app_version_name: String,\n    app_package_name: String,\n  )\n}\n\nClientContextClient(\n  installation_id: String,\n  app_title: String,\n  app_version_name: String,\n  app_package_name: String,\n)\n\n\nSynonyms:\nglambda.ClientContextClient\nglambda ClientContextClient","url":"glambda.html#ClientContextClient"},{"doc":"glambda","title":"ClientContextEnv","content":"pub type ClientContextEnv {\n  ClientContextEnv(\n    platform_version: String,\n    platform: String,\n    make: String,\n    model: String,\n    locale: String,\n  )\n}\n\nClientContextEnv(\n  platform_version: String,\n  platform: String,\n  make: String,\n  model: String,\n  locale: String,\n)\n\n\nSynonyms:\nglambda.ClientContextEnv\nglambda ClientContextEnv","url":"glambda.html#ClientContextEnv"},{"doc":"glambda","title":"CognitoIdentity","content":"pub type CognitoIdentity {\n  CognitoIdentity(\n    cognito_identity_id: String,\n    cognito_identity_pool_id: String,\n  )\n}\n\nCognitoIdentity(\n  cognito_identity_id: String,\n  cognito_identity_pool_id: String,\n)\n\n\nSynonyms:\nglambda.CognitoIdentity\nglambda CognitoIdentity","url":"glambda.html#CognitoIdentity"},{"doc":"glambda","title":"Context","content":"pub type Context {\n  Context(\n    callback_waits_for_empty_event_loop: Bool,\n    function_name: String,\n    function_version: String,\n    invoked_function_arn: String,\n    memory_limit_in_mb: String,\n    aws_request_id: String,\n    log_group_name: String,\n    log_stream_name: String,\n    identity: Option(CognitoIdentity),\n    client_context: Option(ClientContext),\n  )\n}\n\nContext(\n  callback_waits_for_empty_event_loop: Bool,\n  function_name: String,\n  function_version: String,\n  invoked_function_arn: String,\n  memory_limit_in_mb: String,\n  aws_request_id: String,\n  log_group_name: String,\n  log_stream_name: String,\n  identity: Option(CognitoIdentity),\n  client_context: Option(ClientContext),\n)\n\n\nSynonyms:\nglambda.Context\nglambda Context","url":"glambda.html#Context"},{"doc":"glambda","title":"EventBridgeEvent","content":"pub type EventBridgeEvent {\n  EventBridgeEvent(\n    id: String,\n    version: String,\n    account: String,\n    time: String,\n    region: String,\n    resources: List(String),\n    source: String,\n    detail: Dynamic,\n  )\n}\n\nEventBridgeEvent(\n  id: String,\n  version: String,\n  account: String,\n  time: String,\n  region: String,\n  resources: List(String),\n  source: String,\n  detail: Dynamic,\n)\n\n\nSynonyms:\nglambda.EventBridgeEvent\nglambda EventBridgeEvent","url":"glambda.html#EventBridgeEvent"},{"doc":"glambda","title":"Handler","content":"pub type Handler(event, result) =\n  fn(event, Context) -&gt; Promise(result)\n Alias for a strongly typed lambda function\n\nSynonyms:\nglambda.Handler\nglambda Handler","url":"glambda.html#Handler"},{"doc":"glambda","title":"JsContext","content":"pub type JsContext\n Represents the raw JavaScript context for the lambda.\n\nSynonyms:\nglambda.JsContext\nglambda JsContext","url":"glambda.html#JsContext"},{"doc":"glambda","title":"JsEvent","content":"pub type JsEvent\n Represents the raw JavaScript event that invoked the lambda.\n\nSynonyms:\nglambda.JsEvent\nglambda JsEvent","url":"glambda.html#JsEvent"},{"doc":"glambda","title":"JsHandler","content":"pub type JsHandler =\n  fn(JsEvent, JsContext) -&gt; Promise(JsResult)\n Represents the raw Javascript handler for the lambda.\n\nSynonyms:\nglambda.JsHandler\nglambda JsHandler","url":"glambda.html#JsHandler"},{"doc":"glambda","title":"JsResult","content":"pub type JsResult {\n  JsResult\n  Void\n}\n Represents the raw JavaScript response for the lambda.\nJsResult\n\n\nVoid\n\n\nSynonyms:\nglambda.JsResult\nglambda JsResult","url":"glambda.html#JsResult"},{"doc":"glambda","title":"SqsBatchItemFailure","content":"pub type SqsBatchItemFailure {\n  SqsBatchItemFailure(item_identifier: String)\n}\n\nSqsBatchItemFailure(item_identifier: String)\n\n\nSynonyms:\nglambda.SqsBatchItemFailure\nglambda SqsBatchItemFailure","url":"glambda.html#SqsBatchItemFailure"},{"doc":"glambda","title":"SqsBatchResponse","content":"pub type SqsBatchResponse {\n  SqsBatchResponse(\n    batch_item_failures: List(SqsBatchItemFailure),\n  )\n}\n\nSqsBatchResponse(batch_item_failures: List(SqsBatchItemFailure))\n\n\nSynonyms:\nglambda.SqsBatchResponse\nglambda SqsBatchResponse","url":"glambda.html#SqsBatchResponse"},{"doc":"glambda","title":"SqsEvent","content":"pub type SqsEvent {\n  SqsEvent(records: List(SqsRecord))\n}\n\nSqsEvent(records: List(SqsRecord))\n\n\nSynonyms:\nglambda.SqsEvent\nglambda SqsEvent","url":"glambda.html#SqsEvent"},{"doc":"glambda","title":"SqsMessageAttribute","content":"pub type SqsMessageAttribute {\n  SqsMessageAttribute(\n    string_value: Option(String),\n    binary_value: Option(String),\n    string_list_values: Option(List(String)),\n    binary_list_values: Option(List(String)),\n    data_type: String,\n  )\n}\n\nSqsMessageAttribute(\n  string_value: Option(String),\n  binary_value: Option(String),\n  string_list_values: Option(List(String)),\n  binary_list_values: Option(List(String)),\n  data_type: String,\n)\n\n\nSynonyms:\nglambda.SqsMessageAttribute\nglambda SqsMessageAttribute","url":"glambda.html#SqsMessageAttribute"},{"doc":"glambda","title":"SqsRecord","content":"pub type SqsRecord {\n  SqsRecord(\n    message_id: String,\n    receipt_handle: String,\n    body: String,\n    attributes: SqsRecordAttributes,\n    message_attributes: Dict(String, SqsMessageAttribute),\n    md5_of_body: String,\n    event_source: String,\n    event_source_arn: String,\n    aws_region: String,\n  )\n}\n\nSqsRecord(\n  message_id: String,\n  receipt_handle: String,\n  body: String,\n  attributes: SqsRecordAttributes,\n  message_attributes: Dict(String, SqsMessageAttribute),\n  md5_of_body: String,\n  event_source: String,\n  event_source_arn: String,\n  aws_region: String,\n)\n\n\nSynonyms:\nglambda.SqsRecord\nglambda SqsRecord","url":"glambda.html#SqsRecord"},{"doc":"glambda","title":"SqsRecordAttributes","content":"pub type SqsRecordAttributes {\n  SqsRecordAttributes(\n    aws_trace_header: Option(String),\n    approximate_receive_count: String,\n    sent_timestamp: String,\n    sender_id: String,\n    approximate_first_receive_timestamp: String,\n    sequence_number: Option(String),\n    message_group_id: Option(String),\n    message_deduplication_id: Option(String),\n    dead_letter_queue_source_arn: Option(String),\n  )\n}\n\nSqsRecordAttributes(\n  aws_trace_header: Option(String),\n  approximate_receive_count: String,\n  sent_timestamp: String,\n  sender_id: String,\n  approximate_first_receive_timestamp: String,\n  sequence_number: Option(String),\n  message_group_id: Option(String),\n  message_deduplication_id: Option(String),\n  dead_letter_queue_source_arn: Option(String),\n)\n\n\nSynonyms:\nglambda.SqsRecordAttributes\nglambda SqsRecordAttributes","url":"glambda.html#SqsRecordAttributes"},{"doc":"glambda","title":"api_gateway_proxy_v2_handler","content":"pub fn api_gateway_proxy_v2_handler(\n  handler: fn(ApiGatewayProxyEventV2, Context) -&gt;\n    Promise(ApiGatewayProxyResultV2),\n) -&gt; fn(JsEvent, JsContext) -&gt; Promise(JsResult)\n Wraps a handler to create a lambda function to handle API Gateway proxy\n events\nSynonyms:\nglambda.api_gateway_proxy_v2_handler\nglambda api_gateway_proxy_v2_handler","url":"glambda.html#api_gateway_proxy_v2_handler"},{"doc":"glambda","title":"eventbridge_handler","content":"pub fn eventbridge_handler(\n  handler: fn(EventBridgeEvent, Context) -&gt; Promise(Nil),\n) -&gt; fn(JsEvent, JsContext) -&gt; Promise(JsResult)\n Wraps a handler to create a lambda function to handle EventBridge\n events\nSynonyms:\nglambda.eventbridge_handler\nglambda eventbridge_handler","url":"glambda.html#eventbridge_handler"},{"doc":"glambda","title":"http_handler","content":"pub fn http_handler(\n  handler: fn(Request(Option(String)), Context) -&gt;\n    Promise(Response(Option(String))),\n) -&gt; fn(JsEvent, JsContext) -&gt; Promise(JsResult)\n Wraps an HTTP handler to create a lambda function to handle API Gateway proxy\n events\nSynonyms:\nglambda.http_handler\nglambda http_handler","url":"glambda.html#http_handler"},{"doc":"glambda","title":"sqs_handler","content":"pub fn sqs_handler(\n  handler: fn(SqsEvent, Context) -&gt;\n    Promise(Option(SqsBatchResponse)),\n) -&gt; fn(JsEvent, JsContext) -&gt; Promise(JsResult)\n Wraps a handler to create a lambda function to handle SQS\n events\nSynonyms:\nglambda.sqs_handler\nglambda sqs_handler","url":"glambda.html#sqs_handler"},{"doc":"glambda","title":"glambda","content":" This module provides types and adapters to write AWS Lambda functions that target the Node runtime.\n\n The core type of glambda is the `Handler(event, result)`, which is simply a\n function, `fn(event, Context) -&gt; Promise(result)`. Then you use one of the\n handler adapters to wrap your handler to make it compatible with AWS Lambda.\n\n The adapter creates a new function,\n `fn(JsEvent, JsContext) -&gt; Promise(JsResult)`. You shouldn&#39;t need to use\n these types in your code. In fact, you typically do not need to reference\n them at all due to type inference.\n\n # Examples\n\n You can handle API Gateway proxy v2 events using Gleam HTTP types\n\n ```gleam\n fn handle_request(\n   request: Request(Option(String)),\n   ctx: Context,\n ) -&gt; Promise(Response(Option(String))) {\n   Response(200, [], None)\n   |&gt; promise.resolve\n }\n\n // this is the actual function lambda will invoke\n pub fn handler(event, ctx) {\n   glambda.http_handler(handle_request)(event, ctx)\n }\n ```\n\n You can also handle the API Gateway event directly, or several other\n supported event types, such as EventBridge.\n\n ```gleam\n fn handle_request(event: EventBridgeEvent, ctx: Context) -&gt; Promise(Nil) {\n   io.debug(event)\n   promise.resolve(Nil)\n }\n\n // this is the actual function lambda will invoke\n pub fn handler(event, ctx) {\n   glambda.eventbridge_event_handler(handle_request)(event, ctx)\n }\n ```\n # Supported Events\n * `ApiGatewayProxyEventV2` (handled directly or as a `Request(Option(String))`)\n * `EventBridgeEvent`\n * `SqsEvent`\n\n Reference the `*_handler` functions for the correct signatures.","url":"glambda.html"}]);